@@ -200,17 +200,17 @@ def plot_image (app, plot):
         #print("text: %s, pylib: %s" %(text, pylib))
     elif args[0] == "gnuplot":
         size = options.get("size", "900,600")
-        if (plot_format in ["pdf", "eps"] and "," in options["size"]):
+        if (plot_format in ["pdf", "eps"]):
             # pdf unit is inch while png is pixel, convert them.
-            tmp = map(lambda x: int(x.strip())/100, options["size"].split(","))
-            size = ",".join("%d"%(i) for i in tmp)
+            size = ",".join("%d" %(int(i.strip())/100) for i in size.split(","))
 
         lines = StringIO(text).readlines()
-        for l in lines: # reset the output/terminal lines
-            if ('set\s+output' in l or 'set\s+term' in l):
-                lines.remove(l)
+        # Remove the lines with set output/set terminal
+        lines = [l for l in lines if (not re.search("^[^#]*set\s+output", l, flags=0))
+                and (not re.search("^[^#]*set\s+term", l, flags=0))]
         lines.insert(0, 'set output "%s"\n' %(out["outfullfn"]))
-        lines.insert(0, 'set terminal %s size %s\n' %(plot_format, size))
+        terminal = (plot_format == "png") and "pngcairo" or plot_format
+        lines.insert(0, 'set terminal %s size %s\n' %(terminal, size))
         text = ''.join(lines)
         #print("text: %s" %(text))
 
